@@ -37,7 +37,7 @@ except ValueError:
     print "Sorry, requires Python module Cheetah 2.0rc7 or higher."
     sys.exit(1)
 except:
-    print "The following modules need to be installed: Cheetah, cherrypy(included, unpack the zip)"
+    print "The Python module Cheetah is required"
     sys.exit(1)
 
 import cherrypy
@@ -62,20 +62,22 @@ except:
         else:
             SQLITE_DLL = False
 
-import sabnzbd.lang
 import sabnzbd
+import sabnzbd.lang
 import sabnzbd.interface
 from sabnzbd.constants import *
 import sabnzbd.newsunpack
-from sabnzbd.misc import get_user_shellfolders, launch_a_browser, real_path, \
-     check_latest_version, panic_tmpl, panic_port, panic_host, panic_fwall, panic_sqlite, panic, exit_sab, \
-     panic_xport, notify, split_host, get_ext, create_https_certificates, \
+from sabnzbd.misc import get_user_shellfolders, real_path, \
+     check_latest_version, exit_sab, \
+     split_host, get_ext, create_https_certificates, \
      windows_variant, ip_extract, set_serv_parms, get_serv_parms, globber
+from sabnzbd.panic import panic_tmpl, panic_port, panic_host, panic_fwall, \
+     panic_sqlite, panic, launch_a_browser, panic_xport
 import sabnzbd.scheduler as scheduler
 import sabnzbd.config as config
 import sabnzbd.cfg
 import sabnzbd.downloader
-from sabnzbd.encoding import unicoder
+from sabnzbd.encoding import unicoder, latin1
 from sabnzbd.utils import osx
 
 from threading import Thread
@@ -639,9 +641,12 @@ def find_free_port(host, currentport):
     return 0
 
 
-def check_for_sabnzbd(url, upload_nzbs):
+def check_for_sabnzbd(url, upload_nzbs, allow_browser=True):
     """ Check for a running instance of sabnzbd(same version) on this port
+        allow_browser==True|None will launch the browser, False will not.
     """
+    if allow_browser is None:
+        allow_browser = True
     if is_sabnzbd_running(url):
         # Upload any specified nzb files to the running instance
         if upload_nzbs:
@@ -650,8 +655,9 @@ def check_for_sabnzbd(url, upload_nzbs):
                 upload_file(url, f)
         else:
             # Launch the web browser and quit since sabnzbd is already running
+            # Trim away everything after the final slash in the URL
             url = url[:url.rfind('/')+1]
-            launch_a_browser(url, force=True)
+            launch_a_browser(url, force=allow_browser)
         exit_sab(0)
         return True
     return False
@@ -742,6 +748,12 @@ def commandline_handler(frozen=True):
     serv_opts = [os.path.normpath(os.path.abspath(sys.argv[0]))]
     upload_nzbs = []
 
+    # OSX binary: get rid of the weird -psn_0_123456 parameter
+    for arg in sys.argv:
+        if arg.startswith('-psn_'):
+            sys.argv.remove(arg)
+            break
+
     # Ugly hack to remove the extra "SABnzbd*" parameter the Windows binary
     # gets when it's restarted
     if len(sys.argv) > 1 and \
@@ -761,7 +773,7 @@ def commandline_handler(frozen=True):
                                     'weblogging=', 'server=', 'templates',
                                     'template2', 'browser=', 'config-file=', 'force',
                                     'version', 'https=', 'autorestarted', 'repair', 'repair-all',
-                                    'log-all', 'no-login', 'pid=', 'new',
+                                    'log-all', 'no-login', 'pid=', 'new', 'sessions',
                                     # Below Win32 Service options
                                     'password=', 'username=', 'startup=', 'perfmonini=', 'perfmondll=',
                                     'interactive', 'wait=',
@@ -808,6 +820,7 @@ def get_f_option(opts):
 #------------------------------------------------------------------------------
 def main():
     global LOG_FLAG
+    import sabnzbd  # Due to ApplePython bug
 
     autobrowser = None
     autorestarted = False
@@ -833,6 +846,7 @@ def main():
     re_argv = [sys.argv[0]]
     pid_path = None
     new_instance = False
+    force_sessions = False
 
     service, sab_opts, serv_opts, upload_nzbs = commandline_handler()
 
@@ -913,6 +927,8 @@ def main():
             re_argv.append(arg)
         elif opt in ('--new',):
             new_instance = True
+        elif opt in ('--sessions',):
+            force_sessions = True
 
     sabnzbd.MY_FULLNAME = os.path.normpath(os.path.abspath(sabnzbd.MY_FULLNAME))
     sabnzbd.MY_NAME = os.path.basename(sabnzbd.MY_FULLNAME)
@@ -1020,7 +1036,7 @@ def main():
     url = None
     if sabnzbd.WIN32 and not new_instance:
         url = get_connection_info()
-        if url and check_for_sabnzbd(url, upload_nzbs):
+        if url and check_for_sabnzbd(url, upload_nzbs, autobrowser):
             exit_sab(0)
 
     # If an instance of sabnzbd(same version) is already running on this port, launch the browser
@@ -1038,7 +1054,7 @@ def main():
             else:
                 if not url:
                     url = 'https://%s:%s/sabnzbd/api?' % (browserhost, port)
-                if new_instance or not check_for_sabnzbd(url, upload_nzbs):
+                if new_instance or not check_for_sabnzbd(url, upload_nzbs, autobrowser):
                     newport = find_free_port(browserhost, port)
                     if newport > 0:
                         sabnzbd.cfg.https_port.set(newport)
@@ -1058,7 +1074,7 @@ def main():
         else:
             if not url:
                 url = 'http://%s:%s/sabnzbd/api?' % (browserhost, cherryport)
-            if new_instance or not check_for_sabnzbd(url, upload_nzbs):
+            if new_instance or not check_for_sabnzbd(url, upload_nzbs, autobrowser):
                 port = find_free_port(browserhost, cherryport)
                 if port > 0:
                     sabnzbd.cfg.cherryport.set(port)
@@ -1172,6 +1188,7 @@ def main():
     else:
         logging.info('Platform = %s', os.name)
     logging.info('Python-version = %s', sys.version)
+    logging.info('Arguments = %s', sabnzbd.CMDLINE)
 
     # OSX 10.5 I/O priority setting
     if sabnzbd.DARWIN:
@@ -1225,21 +1242,8 @@ def main():
     # Save the INI file
     config.save_config(force=True)
 
-    logging.info('Starting %s-%s', sabnzbd.MY_NAME, sabnzbd.__version__)
-    try:
-        sabnzbd.start()
-    except:
-        logging.exception("Failed to start %s-%s", sabnzbd.MY_NAME, sabnzbd.__version__)
-        sabnzbd.halt()
-
     print_modules()
 
-    # Upload any nzb/zip/rar/nzb.gz files from file association
-    if upload_nzbs:
-        from sabnzbd.utils.upload import add_local
-        for f in upload_nzbs:
-            add_local(f)
-
     cherrylogtoscreen = False
     sabnzbd.WEBLOGFILE = None
 
@@ -1285,6 +1289,14 @@ def main():
         sabnzbd.cfg.username.set('')
         sabnzbd.cfg.password.set('')
 
+    # Fix leakage in memory-based CherryPy session support by using file-based.
+    # However, we don't really need session support.
+    if force_sessions:
+        sessions = sabnzbd.misc.create_real_path('sessions', sabnzbd.cfg.admin_dir.get_path(), 'sessions')[1]
+        sabnzbd.misc.remove_all(sessions, 'session-*.lock', keep_folder=True)
+    else:
+        sessions = None
+
     cherrypy.config.update({'server.environment': 'production',
                             'server.socket_host': cherryhost,
                             'server.socket_port': cherryport,
@@ -1294,10 +1306,13 @@ def main():
                             'engine.reexec_retry' : 100,
                             'tools.encode.on' : True,
                             'tools.gzip.on' : True,
-                            'tools.sessions.on' : True,
+                            'tools.sessions.on' : bool(sessions),
+                            'tools.sessions.storage_type' : 'file',
+                            'tools.sessions.storage_path' : sessions,
+                            'tools.sessions.timeout' : 60,
                             'request.show_tracebacks': True,
                             'checker.check_localhost' : bool(consoleLogging),
-                            'error_page.401': sabnzbd.misc.error_page_401
+                            'error_page.401': sabnzbd.panic.error_page_401
                             })
 
 
@@ -1369,7 +1384,9 @@ def main():
     sabnzbd.BROWSER_URL = browser_url
     if not autorestarted:
         launch_a_browser(browser_url)
-        notify("SAB_Launched", None)
+        if sabnzbd.FOUNDATION:
+            import sabnzbd.osxmenu
+            sabnzbd.osxmenu.notify("SAB_Launched", None)
         osx.sendGrowlMsg('SABnzbd %s' % (sabnzbd.__version__),"http://%s:%s/sabnzbd" % (browserhost, cherryport),osx.NOTIFICATION['startup'])
         # Now's the time to check for a new version
         check_latest_version()
@@ -1399,6 +1416,20 @@ def main():
     if pid_path:
         sabnzbd.pid_file(pid_path, cherryport)
 
+    # Start all SABnzbd tasks
+    logging.info('Starting %s-%s', sabnzbd.MY_NAME, sabnzbd.__version__)
+    try:
+        sabnzbd.start()
+    except:
+        logging.exception("Failed to start %s-%s", sabnzbd.MY_NAME, sabnzbd.__version__)
+        sabnzbd.halt()
+
+    # Upload any nzb/zip/rar/nzb.gz files from file association
+    if upload_nzbs:
+        from sabnzbd.utils.upload import add_local
+        for f in upload_nzbs:
+            add_local(f)
+
     # Have to keep this running, otherwise logging will terminate
     timer = 0
     while not sabnzbd.SABSTOP:
@@ -1488,7 +1519,7 @@ def main():
         mail.send('stop')
     if sabnzbd.WIN32:
         del_connection_info()
-    notify("SAB_Shutdown", None)
+    if sabnzbd.FOUNDATION: sabnzbd.osxmenu.notify("SAB_Shutdown", None)
     logging.info('Leaving SABnzbd')
     sys.stderr.flush()
     sys.stdout.flush()
@@ -1620,6 +1651,8 @@ def HandleCommandLine(allow_service=True):
 #
 if __name__ == '__main__':
 
+    sabnzbd.CMDLINE = ', '.join(['"%s"' % latin1(p) for p in sys.argv])
+
     if sabnzbd.WIN32:
         if not HandleCommandLine(allow_service=not hasattr(sys, "frozen")):
             main()
