@@ -70,6 +70,13 @@ _MSG_NO_SUCH_CONFIG   = 'Config item does not exist'
 _MSG_BAD_SERVER_PARMS = 'Incorrect server settings'
 
 
+#------------------------------------------------------------------------------
+# For Windows: determine executable extensions
+if os.name == 'nt':
+    PATHEXT = os.environ.get('PATHEXT', '').lower().split(';')
+else:
+    PATHEXT = []
+
 #------------------------------------------------------------------------------
 def api_handler(kwargs):
     """ API Dispatcher
@@ -393,15 +400,17 @@ def _api_history(name, output, kwargs):
 
     if name == 'delete':
         special = value.lower()
+        del_files = bool(int_conv(kwargs.get('del_files')))
         if special in ('all', 'failed', 'completed'):
             history_db = cherrypy.thread_data.history_db
-            if value in ('all', 'failed'):
+            if special in ('all', 'failed'):
+                if del_files:
+                    del_job_files(history_db.get_failed_paths())
                 history_db.remove_failed()
-            if value in ('all', 'completed'):
+            if special in ('all', 'completed'):
                 history_db.remove_completed()
             return report(output)
         elif value:
-            del_files = bool(int_conv(kwargs.get('del_files')))
             jobs = value.split(',')
             for job in jobs:
                 del_hist_job(job, del_files)
@@ -1031,6 +1040,8 @@ def build_queue(web_dir=None, root=None, verbose=False, prim=True, verbose_list=
             slot['status'] = "%s" % (status)
         if priority == TOP_PRIORITY:
             slot['priority'] = 'Force'
+        elif priority == REPAIR_PRIORITY:
+            slot['priority'] = 'Repair'
         elif priority == HIGH_PRIORITY:
             slot['priority'] = 'High'
         elif priority == LOW_PRIORITY:
@@ -1367,14 +1378,28 @@ def retry_job(job, new_nzb):
     return False
 
 
+#------------------------------------------------------------------------------
+def del_job_files(job_paths):
+    """ Remove files of each path in the list """
+    for path in job_paths:
+        if path and path.lower().startswith(cfg.download_dir.get_path().lower()):
+            nzbstuff.clean_folder(os.path.join(path, JOB_ADMIN))
+            nzbstuff.clean_folder(path)
+
+
 #------------------------------------------------------------------------------
 def del_hist_job(job, del_files):
     """ Remove history element """
     if job:
-        history_db = cherrypy.thread_data.history_db
-        path = history_db.get_path(job)
-        PostProcessor.do.delete(job, del_files=del_files)
-        history_db.remove_history(job)
+        path = PostProcessor.do.get_path(job)
+        if path:
+            PostProcessor.do.delete(job, del_files=del_files)
+        else:
+            history_db = cherrypy.thread_data.history_db
+            path = history_db.get_path(job)
+            PostProcessor.do.delete(job, del_files=del_files)
+            history_db.remove_history(job)
+
         if path and del_files and path.lower().startswith(cfg.download_dir.get_path().lower()):
             nzbstuff.clean_folder(os.path.join(path, JOB_ADMIN))
             nzbstuff.clean_folder(path)
@@ -1393,7 +1418,7 @@ def Tspec(txt):
 _SKIN_CACHE = {}    # Stores pre-translated acronyms
 
 # This special is to be used in interface.py for template processing
-# to be paased for the $T function: so { ..., 'T' : Ttemplate, ...}
+# to be passed for the $T function: so { ..., 'T' : Ttemplate, ...}
 def Ttemplate(txt):
     """ Translation function for Skin texts
     """
@@ -1506,10 +1531,6 @@ def build_header(prim):
 
 
 #------------------------------------------------------------------------------
-def get_history_size():
-    history_db = cherrypy.thread_data.history_db
-    bytes, month, week = history_db.get_history_size()
-    return (format_bytes(bytes), format_bytes(month), format_bytes(week))
 
 def build_history(start=None, limit=None, verbose=False, verbose_list=None, search=None, failed_only=0):
 
@@ -1756,7 +1777,8 @@ def list_scripts(default=False):
     if path and os.access(path, os.R_OK):
         for script in globber(path):
             if os.path.isfile(script):
-                if (sabnzbd.WIN32 and not (win32api.GetFileAttributes(script) & win32file.FILE_ATTRIBUTE_HIDDEN)) or \
+                if (sabnzbd.WIN32 and os.path.splitext(script)[1].lower() in PATHEXT and \
+                                      not (win32api.GetFileAttributes(script) & win32file.FILE_ATTRIBUTE_HIDDEN)) or \
                    (not sabnzbd.WIN32 and os.access(script, os.X_OK) and not os.path.basename(script).startswith('.')):
                     lst.append(os.path.basename(script))
         lst.insert(0, 'None')
