@@ -24,8 +24,6 @@ import sys
 import logging
 import urllib
 import re
-import webbrowser
-import tempfile
 import shutil
 import threading
 import subprocess
@@ -40,23 +38,10 @@ import sabnzbd.config as config
 import sabnzbd.cfg as cfg
 from sabnzbd.encoding import unicoder, latin1
 
-if sabnzbd.FOUNDATION:
-    import Foundation
-
 RE_VERSION = re.compile('(\d+)\.(\d+)\.(\d+)([a-zA-Z]*)(\d*)')
 RE_UNITS = re.compile('(\d+\.*\d*)\s*([KMGTP]{0,1})', re.I)
 TAB_UNITS = ('', 'K', 'M', 'G', 'T', 'P')
 
-PANIC_NONE  = 0
-PANIC_PORT  = 1
-PANIC_TEMPL = 2
-PANIC_QUEUE = 3
-PANIC_FWALL = 4
-PANIC_OTHER = 5
-PANIC_XPORT = 6
-PANIC_SQLITE = 7
-PANIC_HOST = 8
-
 # Check if strings are defined for AM and PM
 HAVE_AMPM = bool(time.strftime('%p', time.localtime()))
 
@@ -227,7 +212,7 @@ def sanitize_filename(name):
     return name + ext
 
 FL_ILLEGAL = CH_ILLEGAL + ':\x92"'
-FL_LEGAL   = CH_LEGAL + ";''"
+FL_LEGAL   = CH_LEGAL +   "-''"
 uFL_ILLEGAL = FL_ILLEGAL.decode('latin-1')
 uFL_LEGAL   = FL_LEGAL.decode('latin-1')
 
@@ -482,237 +467,6 @@ def set_serv_parms(service, args):
 
 
 
-################################################################################
-# Launch a browser for various purposes
-# including panic messages
-#
-################################################################################
-def MSG_BAD_NEWS():
-    return r'''
-    <html>
-    <head>
-    <title>''' + Ta('Problem with') + ''' %s %s</title>
-    </head>
-    <body>
-    <h1><font color="#0000FF"> %s %s</font></h1>
-    <p align="center">&nbsp;</p>
-    <p align="center"><font size="5">
-    <blockquote>
-        %s
-    </blockquote>
-    <br>%s<br>
-    </body>
-</html>
-'''
-
-def MSG_BAD_FWALL():
-    return Ta(r'''
-    SABnzbd is not compatible with some software firewalls.<br>
-    %s<br>
-    Sorry, but we cannot solve this incompatibility right now.<br>
-    Please file a complaint at your firewall supplier.<br>
-    <br>
-''')
-
-def MSG_BAD_PORT():
-    return Ta(r'''
-    SABnzbd needs a free tcp/ip port for its internal web server.<br>
-    Port %s on %s was tried , but it is not available.<br>
-    Some other software uses the port or SABnzbd is already running.<br>
-    <br>
-    Please restart SABnzbd with a different port number.''') + \
-    '''<br>
-    <br>
-    %s<br>
-      &nbsp;&nbsp;&nbsp;&nbsp;%s --server %s:%s<br>
-    <br>''' + \
-    Ta(r'If you get this error message again, please try a different number.<br>')
-
-def MSG_ILL_PORT():
-    return Ta(r'''
-    SABnzbd needs a free tcp/ip port for its internal web server.<br>
-    Port %s on %s was tried , but the account used for SABnzbd has no permission to use it.<br>
-    On OSX and Linux systems, normal users must use ports above 1023.<br>
-    <br>
-    Please restart SABnzbd with a different port number.''') + \
-    '''<br>
-    <br>
-    %s<br>
-      &nbsp;&nbsp;&nbsp;&nbsp;%s --server %s:%s<br>
-    <br>''' + \
-    Ta(r'If you get this error message again, please try a different number.<br>')
-
-def MSG_BAD_HOST():
-    return Ta(r'''
-    SABnzbd needs a valid host address for its internal web server.<br>
-    You have specified an invalid address.<br>
-    Safe values are <b>localhost</b> and <b>0.0.0.0</b><br>
-    <br>
-    Please restart SABnzbd with a proper host address.''') + \
-    '''<br>
-    <br>
-    %s<br>
-      &nbsp;&nbsp;&nbsp;&nbsp;%s --server %s:%s<br>
-    <br>
-'''
-
-def MSG_BAD_QUEUE():
-    return Ta(r'''
-    SABnzbd detected saved data from an other SABnzbd version<br>
-    but cannot re-use the data of the other program.<br><br>
-    You may want to finish your queue first with the other program.<br><br>
-    After that, start this program with the "--clean" option.<br>
-    This will erase the current queue and history!<br>
-    SABnzbd read the file "%s".''') + \
-    '''<br>
-    <br>
-    %s<br>
-      &nbsp;&nbsp;&nbsp;&nbsp;%s --clean<br>
-    <br>
-'''
-
-def MSG_BAD_TEMPL():
-    return Ta(r'''
-    SABnzbd cannot find its web interface files in %s.<br>
-    Please install the program again.<br>
-    <br>
-''')
-
-def MSG_OTHER():
-    return Ta('SABnzbd detected a fatal error:') + '<br>%s<br><br>%s<br>'
-
-def MSG_OLD_QUEUE():
-    return Ta(r'''
-    SABnzbd detected a Queue and History from an older (0.4.x) release.<br><br>
-    Both queue and history will be ignored and may get lost!<br><br>
-    You may choose to stop SABnzbd and finish the queue with the older program.<br><br>
-    Click OK to proceed to SABnzbd''') + \
-    ('''<br><br><FORM><input type="button" onclick="this.form.action='/.'; this.form.submit(); return false;" value="%s"/></FORM>''' % Ta('OK'))
-
-def MSG_SQLITE():
-    return Ta(r'''
-    SABnzbd detected that the file sqlite3.dll is missing.<br><br>
-    Some poorly designed virus-scanners remove this file.<br>
-    Please check your virus-scanner, try to re-install SABnzbd and complain to your virus-scanner vendor.<br>
-    <br>
-''')
-
-def panic_message(panic, a=None, b=None):
-    """Create the panic message from templates
-    """
-    if sabnzbd.WIN32:
-        os_str = Ta('Press Startkey+R and type the line (example):')
-        prog_path = '"%s"' % sabnzbd.MY_FULLNAME
-    else:
-        os_str = Ta('Open a Terminal window and type the line (example):')
-        prog_path = sabnzbd.MY_FULLNAME
-
-    if panic == PANIC_PORT:
-        newport = int(b) + 1
-        newport = "%s" % newport
-        msg = MSG_BAD_PORT() % (b, a, os_str, prog_path, a, newport)
-    elif panic == PANIC_XPORT:
-        if int(b) < 1023:
-            newport = 1024
-        else:
-            newport = int(b) + 1
-        newport = "%s" % newport
-        msg = MSG_ILL_PORT() % (b, a, os_str, prog_path, a, newport)
-    elif panic == PANIC_TEMPL:
-        msg = MSG_BAD_TEMPL() % a
-    elif panic == PANIC_QUEUE:
-        msg = MSG_BAD_QUEUE() % (a, os_str, prog_path)
-    elif panic == PANIC_FWALL:
-        if a:
-            msg = MSG_BAD_FWALL() % Ta('It is likely that you are using ZoneAlarm on Vista.<br>')
-        else:
-            msg = MSG_BAD_FWALL() % "<br>"
-    elif panic == PANIC_SQLITE:
-        msg = MSG_SQLITE()
-    elif panic == PANIC_HOST:
-        msg = MSG_BAD_HOST() % (os_str, prog_path, 'localhost', b)
-    else:
-        msg = MSG_OTHER() % (a, b)
-
-    msg = MSG_BAD_NEWS() % (sabnzbd.MY_NAME, sabnzbd.__version__, sabnzbd.MY_NAME, sabnzbd.__version__,
-                          msg, Ta('Program did not start!'))
-
-    if sabnzbd.WIN_SERVICE:
-        sabnzbd.WIN_SERVICE.ErrLogger('Panic exit', msg)
-
-    if (not cfg.autobrowser()) or sabnzbd.DAEMON:
-        return
-
-    msgfile, url = tempfile.mkstemp(suffix='.html')
-    os.write(msgfile, msg)
-    os.close(msgfile)
-    return url
-
-
-def panic_fwall(vista):
-    launch_a_browser(panic_message(PANIC_FWALL, vista))
-
-def panic_port(host, port):
-    launch_a_browser(panic_message(PANIC_PORT, host, port))
-
-def panic_host(host, port):
-    launch_a_browser(panic_message(PANIC_HOST, host, port))
-
-def panic_xport(host, port):
-    launch_a_browser(panic_message(PANIC_XPORT, host, port))
-    logging.error(Ta('You have no permisson to use port %s'), port)
-
-def panic_queue(name):
-    launch_a_browser(panic_message(PANIC_QUEUE, name, 0))
-
-def panic_tmpl(name):
-    launch_a_browser(panic_message(PANIC_TEMPL, name, 0))
-
-def panic_sqlite(name):
-    launch_a_browser(panic_message(PANIC_SQLITE, name, 0))
-
-def panic_old_queue():
-    msg = MSG_OLD_QUEUE()
-    return MSG_BAD_NEWS() % (sabnzbd.MY_NAME, sabnzbd.__version__, sabnzbd.MY_NAME, sabnzbd.__version__, msg, '')
-
-def panic(reason, remedy=""):
-    print "\n%s:\n  %s\n%s" % (Ta('Fatal error'), reason, remedy)
-    launch_a_browser(panic_message(PANIC_OTHER, reason, remedy))
-
-
-def launch_a_browser(url, force=False):
-    """Launch a browser pointing to the URL
-    """
-    if not force and not cfg.autobrowser() or sabnzbd.DAEMON:
-        return
-
-    if cfg.enable_https() and not cfg.https_port.get_int():
-        # Must use https, because http is not available
-        url = url.replace('http:', 'https:')
-
-    logging.info("Lauching browser with %s", url)
-    try:
-        webbrowser.open(url, 2, 1)
-    except:
-        logging.warning(Ta('Cannot launch the browser, probably not found'))
-        logging.info("Traceback: ", exc_info = True)
-
-
-def error_page_401(status, message, traceback, version):
-    """ Custom handler for 401 error """
-    title = T('Access denied')
-    body = T('Error %s: You need to provide a valid username and password.') % status
-    return r'''
-<html>
-    <head>
-    <title>%s</title>
-    </head>
-    <body>
-    <br/><br/>
-    <font color="#0000FF">%s</font>
-    </body>
-</html>
-''' % (title, body)
 
 
 
@@ -888,16 +642,6 @@ def exit_sab(value):
     sys.exit(value)
 
 
-#------------------------------------------------------------------------------
-def notify(notificationName, message):
-    """ Send a notification to the OS (OSX-only) """
-    if sabnzbd.FOUNDATION:
-        pool = Foundation.NSAutoreleasePool.alloc().init()
-        nc = Foundation.NSDistributedNotificationCenter.defaultCenter()
-        nc.postNotificationName_object_(notificationName, message)
-        del pool
-
-
 #------------------------------------------------------------------------------
 def split_host(srv):
     """ Split host:port notation, allowing for IPV6 """
@@ -1140,12 +884,9 @@ def on_cleanup_list(filename, skip_nzb=False):
     """
     lst = cfg.cleanup_list()
     if lst:
-        ext = os.path.splitext(filename)[1].strip().strip('.')
-        if sabnzbd.WIN32:
-            ext = ext.lower()
-
+        ext = os.path.splitext(filename)[1].strip().strip('.').lower()
         for k in lst:
-            item = k.strip().strip('.')
+            item = k.strip().strip('.').lower()
             if item == ext and not (skip_nzb and item == 'nzb'):
                 return True
     return False
@@ -1221,34 +962,9 @@ def int_conv(value):
 
 #------------------------------------------------------------------------------
 # Diskfree
-try:
-    os.statvfs
-    import statvfs
-    # posix diskfree
-    def diskfree(_dir):
-        """ Return amount of free diskspace in GBytes
-        """
-        try:
-            s = os.statvfs(_dir)
-            return (s[statvfs.F_BAVAIL] * s[statvfs.F_FRSIZE]) / GIGI
-        except OSError:
-            return 0.0
-    def disktotal(_dir):
-        """ Return amount of total diskspace in GBytes
-        """
-        try:
-            s = os.statvfs(_dir)
-            return (s[statvfs.F_BLOCKS] * s[statvfs.F_FRSIZE]) / GIGI
-        except OSError:
-            return 0.0
-
-except AttributeError:
-
-    try:
-        import win32api
-    except ImportError:
-        pass
+if sabnzbd.WIN32:
     # windows diskfree
+    import win32api
     def diskfree(_dir):
         """ Return amount of free diskspace in GBytes
         """
@@ -1265,6 +981,37 @@ except AttributeError:
             return disk_size / GIGI
         except:
             return 0.0
+else:
+    try:
+        os.statvfs
+        # posix diskfree
+        def diskfree(_dir):
+            """ Return amount of free diskspace in GBytes
+            """
+            try:
+                s = os.statvfs(_dir)
+                if s.f_bavail < 0:
+                    return float(sys.maxint) * float(s.f_frsize) / GIGI
+                else:
+                    return float(s.f_bavail) * float(s.f_frsize) / GIGI
+            except OSError:
+                return 0.0
+        def disktotal(_dir):
+            """ Return amount of total diskspace in GBytes
+            """
+            try:
+                s = os.statvfs(_dir)
+                if s.f_blocks < 0:
+                    return float(sys.maxint) * float(s.f_frsize) / GIGI
+                else:
+                    return float(s.f_blocks) * float(s.f_frsize) / GIGI
+            except OSError:
+                return 0.0
+    except ImportError:
+        def diskfree(_dir):
+            return 10.0
+        def disktotal(_dir):
+            return 20.0
 
 
 def create_https_certificates(ssl_cert, ssl_key):
@@ -1355,208 +1102,6 @@ def ip_extract():
     return ips
 
 
-#------------------------------------------------------------------------------
-# Power management for Windows
-
-def win_hibernate():
-    """ Hibernate Windows system, returns after wakeup
-    """
-    try:
-        subprocess.Popen("rundll32 powrprof.dll,SetSuspendState Hibernate")
-        time.sleep(10)
-    except:
-        logging.error(Ta('Failed to hibernate system'))
-        logging.info("Traceback: ", exc_info = True)
-
-
-def win_standby():
-    """ Standby Windows system, returns after wakeup
-    """
-    try:
-        subprocess.Popen("rundll32 powrprof.dll,SetSuspendState Standby")
-        time.sleep(10)
-    except:
-        logging.error(Ta('Failed to standby system'))
-        logging.info("Traceback: ", exc_info = True)
-
-
-def win_shutdown():
-    """ Shutdown Windows system, never returns
-    """
-    try:
-        import win32security
-        import win32api
-        import ntsecuritycon
-
-        flags = ntsecuritycon.TOKEN_ADJUST_PRIVILEGES | ntsecuritycon.TOKEN_QUERY
-        htoken = win32security.OpenProcessToken(win32api.GetCurrentProcess(), flags)
-        id_ = win32security.LookupPrivilegeValue(None, ntsecuritycon.SE_SHUTDOWN_NAME)
-        newPrivileges = [(id_, ntsecuritycon.SE_PRIVILEGE_ENABLED)]
-        win32security.AdjustTokenPrivileges(htoken, 0, newPrivileges)
-        win32api.InitiateSystemShutdown("", "", 30, 1, 0)
-    finally:
-        os._exit(0)
-
-
-#------------------------------------------------------------------------------
-# Power management for OSX
-
-def osx_shutdown():
-    """ Shutdown OSX system, never returns
-    """
-    try:
-        subprocess.call(['osascript', '-e', 'tell app "System Events" to shut down'])
-    except:
-        logging.error(Ta('Error while shutting down system'))
-        logging.info("Traceback: ", exc_info = True)
-    os._exit(0)
-
-
-def osx_standby():
-    """ Make OSX system sleep, returns after wakeup
-    """
-    try:
-        subprocess.call(['osascript', '-e','tell app "System Events" to sleep'])
-        time.sleep(10)
-    except:
-        logging.error(Ta('Failed to standby system'))
-        logging.info("Traceback: ", exc_info = True)
-
-
-def osx_hibernate():
-    """ Make OSX system sleep, returns after wakeup
-    """
-    osx_standby()
-
-
-#------------------------------------------------------------------------------
-# Power management for linux.
-#
-#    Requires DBus plus either HAL [1] or the more modern ConsoleKit [2] and
-#    DeviceKit(-power) [3]. HAL will eventually be deprecated but older systems
-#    might still use it.
-#    [1] http://people.freedesktop.org/~hughsient/temp/dbus-interface.html
-#    [2] http://www.freedesktop.org/software/ConsoleKit/doc/ConsoleKit.html
-#    [3] http://hal.freedesktop.org/docs/DeviceKit-power/
-#
-#    Original code was contributed by Marcel de Vries <marceldevries@phannet.cc>
-#
-
-try:
-    import dbus
-    HAVE_DBUS = True
-except ImportError:
-    HAVE_DBUS = False
-
-
-def _get_sessionproxy():
-    """ Return (proxy-object, interface), (None, None) if not available
-    """
-    name = 'org.freedesktop.PowerManagement'
-    path = '/org/freedesktop/PowerManagement'
-    interface = 'org.freedesktop.PowerManagement'
-    try:
-        bus = dbus.SessionBus()
-        return bus.get_object(name, path), interface
-    except dbus.exceptions.DBusException:
-        return None, None
-
-def _get_systemproxy(method):
-    """ Return (proxy-object, interface, pinterface), (None, None, None) if not available
-    """
-    if method == 'ConsoleKit':
-        name = 'org.freedesktop.ConsoleKit'
-        path = '/org/freedesktop/ConsoleKit/Manager'
-        interface = 'org.freedesktop.ConsoleKit.Manager'
-        pinterface = None
-    elif method == 'DeviceKit':
-        name = 'org.freedesktop.DeviceKit.Power'
-        path = '/org/freedesktop/DeviceKit/Power'
-        interface = 'org.freedesktop.DeviceKit.Power'
-        pinterface = 'org.freedesktop.DBus.Properties'
-    elif method == 'UPower':
-        name = 'org.freedesktop.UPower'
-        path = '/org/freedesktop/UPower'
-        interface = 'org.freedesktop.UPower'
-        pinterface = 'org.freedesktop.DBus.Properties'
-    try:
-        bus = dbus.SystemBus()
-        return bus.get_object(name, path), interface, pinterface
-    except dbus.exceptions.DBusException, msg:
-        logging.info('DBus not reachable (%s)', msg)
-        return None, None, None
-
-
-def linux_shutdown():
-    """ Make Linux system shutdown, never returns
-    """
-    if not HAVE_DBUS: os._exit(0)
-
-    proxy, interface = _get_sessionproxy()
-    if proxy:
-        if proxy.CanShutdown():
-            proxy.Shutdown(dbus_interface=interface)
-    else:
-        proxy, interface, pinterface = _get_systemproxy('ConsoleKit')
-        if proxy:
-            if proxy.CanStop(dbus_interface=interface):
-                try:
-                    proxy.Stop(dbus_interface=interface)
-                except dbus.exceptions.DBusException, msg:
-                    logging.info('Received a DBus exception %s', latin1(msg))
-        else:
-            logging.info('DBus does not support Stop (shutdown)')
-    os._exit(0)
-
-
-def linux_hibernate():
-    """ Make Linux system go into hibernate, returns after wakeup
-    """
-    if not HAVE_DBUS: return
-
-    proxy, interface = _get_sessionproxy()
-    if proxy:
-        if proxy.CanHibernate():
-            proxy.Hibernate(dbus_interface=interface)
-    else:
-        proxy, interface, pinterface = _get_systemproxy('UPower')
-        if not proxy:
-            proxy, interface, pinterface = _get_systemproxy('DeviceKit')
-        if proxy:
-            if proxy.Get(interface, 'can-hibernate', dbus_interface=pinterface):
-                try:
-                    proxy.Hibernate(dbus_interface=interface)
-                except dbus.exceptions.DBusException, msg:
-                    logging.info('Received a DBus exception %s', latin1(msg))
-        else:
-            logging.info('DBus does not support Hibernate')
-    time.sleep(10)
-
-
-def linux_standby():
-    """ Make Linux system go into standby, returns after wakeup
-    """
-    if not HAVE_DBUS: return
-
-    proxy, interface = _get_sessionproxy()
-    if proxy:
-        if proxy.CanSuspend():
-            proxy.Suspend(dbus_interface=interface)
-    else:
-        proxy, interface, pinterface = _get_systemproxy('UPower')
-        if not proxy:
-            proxy, interface, pinterface = _get_systemproxy('DeviceKit')
-        if proxy:
-            if proxy.Get(interface, 'can-suspend', dbus_interface=pinterface):
-                try:
-                    proxy.Suspend(dbus_interface=interface)
-                except dbus.exceptions.DBusException, msg:
-                    logging.info('Received a DBus exception %s', latin1(msg))
-        else:
-            logging.info('DBus does not support Suspend (standby)')
-    time.sleep(10)
-
-
 #------------------------------------------------------------------------------
 
 def renamer(old, new):
@@ -1599,16 +1144,17 @@ def remove_dir(path):
         os.rmdir(path)
 
 
-def remove_all(path, pattern='*'):
+def remove_all(path, pattern='*', keep_folder=False):
     """ Remove folder and all its content
     """
     if os.path.exists(path):
         for f in globber(path, pattern):
             os.remove(f)
-        try:
-            os.rmdir(path)
-        except:
-            pass
+        if not keep_folder:
+            try:
+                os.rmdir(path)
+            except:
+                pass
 
 
 def clean_folder(path, pattern='*'):
