@@ -27,13 +27,14 @@ import datetime
 import sabnzbd
 from sabnzbd.trylist import TryList
 from sabnzbd.nzbstuff import NzbObject
-from sabnzbd.misc import panic_queue, exit_sab, cat_to_opts, \
+from sabnzbd.misc import exit_sab, cat_to_opts, \
                          get_admin_path, remove_all, globber
+from sabnzbd.panic import panic_queue
 import sabnzbd.database as database
 from sabnzbd.decorators import NZBQUEUE_LOCK, synchronized, synchronized_CV
 from sabnzbd.constants import QUEUE_FILE_NAME, QUEUE_VERSION, FUTURE_Q_FOLDER, JOB_ADMIN, \
                               LOW_PRIORITY, NORMAL_PRIORITY, HIGH_PRIORITY, TOP_PRIORITY, \
-                              PNFO_BYTES_FIELD, PNFO_BYTES_LEFT_FIELD
+                              REPAIR_PRIORITY, PNFO_BYTES_FIELD, PNFO_BYTES_LEFT_FIELD
 import sabnzbd.cfg as cfg
 from sabnzbd.articlecache import ArticleCache
 import sabnzbd.downloader
@@ -57,7 +58,6 @@ class NzbQueue(TryList):
         self.__nzo_list = []
         self.__nzo_table = {}
 
-        self.__auto_sort = cfg.auto_sort()
         NzbQueue.do = self
 
     def read_queue(self, repair):
@@ -230,7 +230,7 @@ class NzbQueue(TryList):
                     future.priority = None
                 self.set_priority(future.nzo_id, priority)
 
-                if self.__auto_sort:
+                if cfg.auto_sort():
                     self.sort_by_avg_age()
 
                 self.reset_try_list()
@@ -278,8 +278,6 @@ class NzbQueue(TryList):
     @synchronized(NZBQUEUE_LOCK)
     def add(self, nzo, save=True, quiet=False):
         assert isinstance(nzo, NzbObject)
-        sabnzbd.QUEUECOMPLETEACTION_GO = False
-
         if not nzo.nzo_id:
             nzo.nzo_id = sabnzbd.get_new_id('nzo', nzo.workpath, self.__nzo_table)
 
@@ -297,9 +295,8 @@ class NzbQueue(TryList):
             nzo.deleted = False
             priority = nzo.priority
             self.__nzo_table[nzo.nzo_id] = nzo
-            if priority == TOP_PRIORITY:
-                #A top priority item (usually a completed download fetching pars)
-                #is added to the top of the queue
+            if priority > HIGH_PRIORITY:
+                #Top and repair priority items are added to the top of the queue
                 self.__nzo_list.insert(0, nzo)
             elif priority == LOW_PRIORITY:
                 self.__nzo_list.append(nzo)
@@ -314,9 +311,9 @@ class NzbQueue(TryList):
                     for position in self.__nzo_list:
                         if position.priority < priority:
                             self.__nzo_list.insert(pos, nzo)
-                            added=True
+                            added = True
                             break
-                        pos+=1
+                        pos += 1
                     if not added:
                         #if there are no other items classed as a lower priority
                         #then it will be added to the bottom of the queue
@@ -330,7 +327,7 @@ class NzbQueue(TryList):
             if not (quiet or nzo.status in ('Fetching',)):
                 osx.sendGrowlMsg(T('NZB added to queue'), nzo.filename, osx.NOTIFICATION['download'])
 
-        if self.__auto_sort:
+        if cfg.auto_sort():
             self.sort_by_avg_age()
 
     @synchronized(NZBQUEUE_LOCK)
@@ -688,20 +685,28 @@ class NzbQueue(TryList):
                     logging.warning(Ta('%s -> Unknown encoding'), filename)
 
         if post_done:
-            if not self.__nzo_list:
-                # Close server connections
-                if cfg.autodisconnect():
-                    sabnzbd.downloader.Downloader.do.disconnect()
-
-                # Sets the end-of-queue back on if disabled
-                # adding an nzb and re-adding for more blocks disables it
-                if sabnzbd.QUEUECOMPLETEACTION:
-                    sabnzbd.QUEUECOMPLETEACTION_GO = True
+            if self.actives(grabs=False) < 2 and cfg.autodisconnect():
+                # This was the last job, close server connections
+                sabnzbd.downloader.Downloader.do.disconnect()
 
             # Notify assembler to call postprocessor
             Assembler.do.process((nzo, None))
 
 
+    @synchronized(NZBQUEUE_LOCK)
+    def actives(self, grabs=True):
+        """ Return amount of non-paused jobs, optionally with 'grabbing' items
+        """
+        n = 0
+        for nzo in self.__nzo_list:
+            # Ignore any items that are paused
+            if grabs and nzo.status == 'Grabbing':
+                n += 1
+            elif nzo.status not in ('Paused', 'Grabbing'):
+                n += 1
+        return n
+
+
     @synchronized(NZBQUEUE_LOCK)
     def queue_info(self, for_cli = False):
         bytes_left = 0
@@ -778,17 +783,20 @@ def _nzo_size_cmp(nzo1, nzo2):
     return cmp(nzo1.bytes, nzo2.bytes)
 
 def sort_queue_function(nzo_list, method, reverse):
+    ultra_high_priority = [nzo for nzo in nzo_list if nzo.priority == REPAIR_PRIORITY]
     super_high_priority = [nzo for nzo in nzo_list if nzo.priority == TOP_PRIORITY]
     high_priority = [nzo for nzo in nzo_list if nzo.priority == HIGH_PRIORITY]
     normal_priority = [nzo for nzo in nzo_list if nzo.priority == NORMAL_PRIORITY]
     low_priority = [nzo for nzo in nzo_list if nzo.priority == LOW_PRIORITY]
 
+    ultra_high_priority.sort(cmp=method, reverse=reverse)
     super_high_priority.sort(cmp=method, reverse=reverse)
     high_priority.sort(cmp=method, reverse=reverse)
     normal_priority.sort(cmp=method, reverse=reverse)
     low_priority.sort(cmp=method, reverse=reverse)
 
-    new_list = super_high_priority
+    new_list = ultra_high_priority
+    new_list.extend(super_high_priority)
     new_list.extend(high_priority)
     new_list.extend(normal_priority)
     new_list.extend(low_priority)
