@@ -22,6 +22,19 @@
 #NOTIFICATION = {'startup':'grwl-notif-startup','download':'grwl-notif-dl','pp':'grwl-notif-pp','other':'grwl-notif-other'}
 NOTIFICATION = {'startup':'1. On Startup/Shutdown','download':'2. On adding NZB','pp':'3. On post-processing','complete':'4. On download terminated','other':'5. Other Messages'}
 
+# For a future release, make texts translatable.
+if 0:
+    #------------------------------------------------------------------------------
+    # Define translatable message table
+    TT = lambda x:x
+    _NOTIFICATION = {
+        'startup'  : TT('Startup/Shutdown'),        #: Message class for Growl server
+        'download' : TT('Added NZB'),               #: Message class for Growl server
+        'pp'       : TT('Post-processing started'), #: Message class for Growl server
+        'complete' : TT('Job finished'),            #: Message class for Growl server
+        'other'    : TT('Other Messages')           #: Message class for Growl server
+    }
+
 try:
     import Growl
     import os.path
